## Problem

Shutdown of bazel server process via `bazel --batch` or `bazel shutdown` seems
to invalidate `action_listener` caches.

## Expected Behavior

The output should show no execution of the listener:

``` sh
# First build
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true

# Next builds should not show any evidence of listener execution
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true
INFO: Found 1 target...
Target //:true up-to-date:
  bazel-bin/true
INFO: Elapsed time: 0.243s, Critical Path: 0.00s
```

## Observed Behavior

### bazel --batch

To reproduce, use `bazel --batch` multiple times (note the "listening" output):

``` sh
bazel --bazelrc=/dev/null --batch build --experimental_action_listener=//:listener //:true
# INFO: Found 1 target...
# INFO: From Executing extra_action //:cpp_action on //:true:
# listening
# Target //:true up-to-date:
#   bazel-bin/true
# INFO: Elapsed time: 1.197s, Critical Path: 0.09s

# Next build shows that listener was executed again (but not the compiler,
# according to "bazel build -s")
bazel --bazelrc=/dev/null --batch build --experimental_action_listener=//:listener //:true
```

The presence of "listening" in the output indicates that the listener was
executed. This is also observable with `bazel build -s`.

### bazel shutdown

Another way to reproduce the problem is `bazel shutdown`:

``` sh
# First build
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true

# Next build yields expected no-op behavior
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true

# "bazel shutdown" also seems to invalidate the action_listener cache
bazel shutdown

# Next build yields unexpected listener execution
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true

# Next build yields expected no-op behavior
bazel --bazelrc=/dev/null build --experimental_action_listener=//:listener //:true
```
